@@ -14,24 +14,25 @@ my $reader = WebService::Google::Reader->new(
 # Unsubscribe from all feeds.
 my @feeds = $reader->feeds;
 die $reader->error if $reader->error;
-$reader->unsubscribe( @feeds ) or die $reader->error;
+$reader->unsubscribe(@feeds) or die $reader->error;
 printf "Removed %d feeds\n", scalar @feeds;
 
 # Delete all tags.
 my @tags = $reader->tags;
 die $reader->error if $reader->error;
-$reader->delete_tag( @tags ) or die $reader->error;
+$reader->delete_tag(@tags) or die $reader->error;
 printf "Deleted %d tags\n", scalar @tags;
 
 # Remove all states from any entries.
-for my $state ( $reader->_states ) {
-    my $feed = $reader->state( $state, count => 500 ) or next;
+for my $state ($reader->_states) {
+    my $feed = $reader->state($state, count => 500) or next;
 
     do {
-        $reader->unstate_entry( [ $feed->entries ], $reader->_states )
+        $reader->unstate_entry([ $feed->entries ], $reader->_states)
             or die $reader->error;
-        my $count = scalar $feed->entries;
-        printf "Removed state '%s' from %d entries\n", $state, $count if $count;
+        if (my $count = scalar $feed->entries) {
+            printf "Removed state '%s' from %d entries\n", $state, $count;
+        }
         sleep 1;
-    } while ( $reader->more( $feed ) );
+    } while ($reader->more($feed));
 }
