@@ -6,15 +6,15 @@ use parent qw(Exporter);
 
 our @EXPORT = do {
     no strict 'refs';
-    ( qw(NS_GOOGLE_READER), grep(/_URL$/, keys %{__PACKAGE__.'::'}), )
+    grep /^NS_|_URL$/, keys %{__PACKAGE__.'::'}
 };
 
 use constant LOGIN_URL => 'https://www.google.com/accounts/ClientLogin';
 use constant READER_URL => 'http://www.google.com/reader';
 use constant TOKEN_URL => READER_URL.'/api/0/token';
 
-use constant ATOM_URL => READER_URL.'/atom/';
-use constant ATOM_PUBLIC_URL => READER_URL.'/public/atom/';
+use constant ATOM_URL => READER_URL.'/atom';
+use constant ATOM_PUBLIC_URL => READER_URL.'/public/atom';
 use constant API_URL => READER_URL.'/api/0';
 use constant PING_URL => READER_URL.'/ping';
 use constant EXPORT_SUBS_URL => READER_URL.'/subscriptions/export';
@@ -36,9 +36,7 @@ use constant LIST_USER_INFO_URL => READER_URL.'/user-info';
 
 use constant STREAM_ITEM_IDS_URL => API_URL.'/stream/items/ids';
 use constant SEARCH_ITEM_IDS_URL => API_URL.'/search/items/ids';
-use constant STREAM_FEED_CONTENTS_URL => API_URL.'/stream/contents';
-# Deprecated in favor of STREAM_FEED_CONTENTS_URL?
-use constant STREAM_ITEM_CONTENTS_URL => API_URL.'/stream/items/contents';
+use constant STREAM_ITEMS_CONTENTS_URL => API_URL.'/stream/items/contents';
 
 use constant NS_GOOGLE_READER =>
     'http://www.google.com/schemas/reader/atom/';
